==> haskell-mustache-2.4.3.1-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mustache
version:              2.4.3.1
visibility:           public
id:                   mustache-2.4.3.1-1VXnYjXwT7xI4UpqWjfCrR
key:                  mustache-2.4.3.1-1VXnYjXwT7xI4UpqWjfCrR
license:              BSD-3-Clause
copyright:            (c) 2015 - 2022 Justus Adam
maintainer:           dev@justus.science
author:               Justus Adam
homepage:             https://github.com/JustusAdam/mustache#readme
synopsis:             A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.

    Implements the mustache spec version 1.1.3.

    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.

category:             Development
abi:                  730fe6ff8e477115ed5e9b9ac453517d
exposed:              True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types

hidden-modules:       Text.Mustache.Internal Text.Mustache.Internal.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mustache-2.4.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mustache-2.4.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mustache-2.4.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mustache
hs-libraries:         HSmustache-2.4.3.1-1VXnYjXwT7xI4UpqWjfCrR
depends:
    aeson-2.1.2.1-3LOl3stht3x9JybSpHkoQT base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 parsec-3.1.16.1
    scientific-0.3.8.0-APNnjCxblnoKMeXmBXkKkr template-haskell-2.19.0.0
    text-2.0.2 th-lift-0.8.6-HRVeiGNnDxNElRy2LmdExl
    unordered-containers-0.2.20.1-98Hg6PuNW0XDqLHXL1727Z
    vector-0.13.2.0-24VaMY7coOLw3wI0c1W3K

haddock-interfaces:   /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html:         /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mustache-2.4.3.1-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mustache
version:              2.4.3.1
visibility:           public
id:                   mustache-2.4.3.1-7IUT68XNy2D7lS9dA7UUxM
key:                  mustache-2.4.3.1-7IUT68XNy2D7lS9dA7UUxM
license:              BSD-3-Clause
copyright:            (c) 2015 - 2022 Justus Adam
maintainer:           dev@justus.science
author:               Justus Adam
homepage:             https://github.com/JustusAdam/mustache#readme
synopsis:             A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.

    Implements the mustache spec version 1.1.3.

    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.

category:             Development
abi:                  c3865dc058df4854d044f1284d49b861
exposed:              True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types

hidden-modules:       Text.Mustache.Internal Text.Mustache.Internal.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mustache-2.4.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mustache-2.4.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mustache-2.4.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mustache
hs-libraries:         HSmustache-2.4.3.1-7IUT68XNy2D7lS9dA7UUxM
depends:
    aeson-2.1.2.1-LEWFZomfRabp1ORmI1Rne base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 parsec-3.1.16.1
    scientific-0.3.8.0-9gOL1qaAy2CzOZP0iULD0 template-haskell-2.19.0.0
    text-2.0.2 th-lift-0.8.6-HRVeiGNnDxNElRy2LmdExl
    unordered-containers-0.2.20.1-IBPGLFAI2UT5SDMJrMkgk8
    vector-0.13.2.0-JUxTFkVHiOCDvdzFqkdqvm

haddock-interfaces:   /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html:         /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
